@@ -34,5 +34,5 @@ control.logLik.ergm<-function(nsteps=20,
   for(arg in names(formal.args))
     control[arg]<-list(get(arg))
 
-  set.control.class()
+  set.control.class("control.logLik.ergm")
 }
