@@ -120,7 +120,7 @@ ergm <- function(formula, response=NULL,
                  estimate=c("MLE", "MPLE", "CD"),
                  control=control.ergm(),
                  verbose=FALSE,...) {
-  check.control.class()
+  check.control.class("ergm", "ergm")
   control.toplevel(control,...)
   
   estimate <- match.arg(estimate)
@@ -135,7 +135,7 @@ ergm <- function(formula, response=NULL,
   }
   
   if(!is.null(control$seed))  set.seed(as.integer(control$seed))
-  if (verbose) cat("Evaluating network in model\n")
+  if (verbose) message("Evaluating network in model.")
   
   nw <- ergm.getnetwork(formula)
   proposalclass <- "c"
@@ -166,7 +166,7 @@ ergm <- function(formula, response=NULL,
     san.control <- control$SAN.control
     san.control$coef <- san.control$coef[!offset.terms]
     
-    if(verbose) cat("Constructing an approximate response network.\n")
+    if(verbose) message("Constructing an approximate response network.")
     ## If target.stats are given, overwrite the given network and formula
     ## with SAN-ed network and formula.
     if(control$SAN.maxit > 0){
@@ -181,15 +181,15 @@ ergm <- function(formula, response=NULL,
         nw.stats <- summary(remove.offset.formula(formula),response=response)
         srun <- srun + 1
         if(verbose){
-          cat(paste("Finished SAN run",srun,"\n"))
+          message(paste("Finished SAN run",srun,""))
         }
         if(verbose){
-          cat("SAN summary statistics:\n")
-          print(nw.stats)
-          cat("Meanstats Goal:\n")
-          print(target.stats)
-          cat("Difference: SAN target.stats - Goal target.stats =\n")
-          print(round(nw.stats-target.stats,0))
+          message("SAN summary statistics:")
+          .message_print(nw.stats)
+          message("Meanstats Goal:")
+          .message_print(target.stats)
+          message("Difference: SAN target.stats - Goal target.stats =")
+          .message_print(round(nw.stats-target.stats,0))
         }
         if(sum((nw.stats-target.stats)^2) <= 5) break
       }
@@ -214,19 +214,17 @@ ergm <- function(formula, response=NULL,
     if (network.edgecount(nw) == 0) warning("Network is empty and no target stats are specified.")
   }
   
-  if (verbose) cat("Initializing Metropolis-Hastings proposal(s):") 
+  if (verbose) message("Initializing Metropolis-Hastings proposal(s):",appendLF=FALSE) 
   
   MHproposal <- MHproposal(constraints, weights=control$MCMC.prop.weights, control$MCMC.prop.args, nw, class=proposalclass,reference=reference,response=response)
-  if (verbose) cat(" ",MHproposal$pkgname,":MH_",MHproposal$name,sep="")
+  if (verbose) message(" ",MHproposal$pkgname,":MH_",MHproposal$name)
   
   
   if(!is.null(MHproposal.obs)){
     MHproposal.obs <- MHproposal(MHproposal.obs, weights=control$obs.MCMC.prop.weights, control$obs.MCMC.prop.args, nw, class=proposalclass, reference=reference, response=response)
-    if (verbose) cat(" ",MHproposal.obs$pkgname,":MH_",MHproposal.obs$name,sep="")
+    if (verbose) message(" ",MHproposal.obs$pkgname,":MH_",MHproposal.obs$name)
   }
   
-  if(verbose) cat("\n")
-  
   # conddeg MPLE only handles tetrad toggles, so it must be restricted:
   conddeg <- switch(!is.directed(nw) && ("degrees" %in% names(MHproposal$arguments$constraints) ||
                                            all(c("b1degrees","b2degrees") %in% names(MHproposal$arguments$constraints))),
@@ -234,7 +232,7 @@ ergm <- function(formula, response=NULL,
                     NULL)
   if(!is.null(conddeg)) .Deprecated("Contrastive Divergence", old="Degree-Conditioned MPLE")
   
-  if (verbose) cat("Initializing model.\n")
+  if (verbose) message("Initializing model.")
   
   # Construct the initial model.
   
@@ -249,21 +247,25 @@ ergm <- function(formula, response=NULL,
   if("MPLE" %in% init.candidates && !is.dyad.independent(MHproposal$arguments$constraints,
                                                          MHproposal.obs$arguments$constraints) && is.null(conddeg)){
     init.candidates <- init.candidates[init.candidates!="MPLE"]
-    if(verbose) cat("MPLE cannot be used for this constraint structure.\n")
+    if(verbose) message("MPLE cannot be used for this constraint structure.")
   }
   if("MPLE" %in% init.candidates && !is.null(target.stats) && is.curved(formula, response=response)){
     init.candidates <- init.candidates[init.candidates!="MPLE"]
-    if(verbose) cat("At this time, MPLE cannot be used for curved families when target.stats are passed.\n")
+    if(verbose) message("At this time, MPLE cannot be used for curved families when target.stats are passed.")
   }
   control$init.method <- match.arg(control$init.method, init.candidates)
-  if(verbose) cat(paste0("Using initial method '",control$init.method,"'.\n"))
+  if(verbose) message(paste0("Using initial method '",control$init.method,"'."))
   model.initial <- ergm.getmodel(formula, nw, response=response, initialfit=control$init.method=="MPLE")
   
   # If some control$init is specified...
   if(!is.null(control$init)){
     # Check length of control$init.
     if (length(control$init)!=length(model.initial$etamap$offsettheta)) {
-      if(verbose) cat("control$init is", control$init, "\n", "number of statistics is",length(model.initial$coef.names), "\n")
+      if(verbose){
+        message("control$init =")
+        .message_print(control$init)
+        message("number of statistics is ",length(model.initial$coef.names), "")
+      }
       stop(paste("Invalid starting parameter vector control$init:",
                  "wrong number of parameters.",
                  "If you are passing output from another ergm run as control$init,",
@@ -304,7 +306,7 @@ ergm <- function(formula, response=NULL,
       stop("Maximum Pseudo-Likelihood (MPLE) estimation for ERGMs with dyad-dependent constraints is only implemented for certain degree constraints at this time.")
   }
   
-  if (verbose) { cat("Fitting initial model.\n") }
+  if (verbose) { message("Fitting initial model.") }
   
   MPLE.is.MLE <- (MHproposal$reference$name=="Bernoulli"
                   && is.dyad.independent(model.initial)
@@ -323,7 +325,7 @@ ergm <- function(formula, response=NULL,
   # Short-circuit the optimization if all terms are either offsets or dropped.
   if(all(model.initial$etamap$offsettheta)){
     # Note that this cannot be overridden with control$force.main.
-    cat("All terms are either offsets or extreme values. No optimization is performed.\n")
+    message("All terms are either offsets or extreme values. No optimization is performed.")
     return(structure(list(coef=control$init,
                           iterations=0,
                           loglikelihood=NA,
@@ -394,9 +396,9 @@ ergm <- function(formula, response=NULL,
     
     if(eval.loglik) initialfit$null.lik <- logLikNull.ergm(initialfit, verbose=verbose)
     if(any(!model.initial$etamap$offsettheta) && eval.loglik){
-      cat("Evaluating log-likelihood at the estimate. ")
+      message("Evaluating log-likelihood at the estimate. ",appendLF=FALSE)
       initialfit<-logLik.ergm(initialfit, add=TRUE, control=control$loglik.control, verbose=verbose)
-      cat("\n")
+      message("")
     }
     return(initialfit)
   }
@@ -439,7 +441,7 @@ ergm <- function(formula, response=NULL,
   model$nw.stats <- summary(model$formula, response=response)
   model$target.stats <- if(!is.null(target.stats)) target.stats else model$nw.stats
   
-  if (verbose) cat("Fitting ERGM.\n")
+  if (verbose) message("Fitting ERGM.")
   mainfit <- switch(control$main.method,
                     "Robbins-Monro" = ergm.robmon(init, nw, model, 
                                                   MHproposal=MHproposal, verbose=verbose, control=control),
@@ -474,7 +476,7 @@ ergm <- function(formula, response=NULL,
   
   if(!is.null(control$MCMLE.check.degeneracy) && control$MCMLE.check.degeneracy && (is.null(mainfit$theta1$independent) || !all(mainfit$theta1$independent))){
     if(verbose) {
-      cat("Checking for degeneracy.\n")
+      message("Checking for degeneracy.")
     }
     degeneracy <- ergm.degeneracy(mainfit, test.only=TRUE)
   } else {
@@ -512,7 +514,7 @@ ergm <- function(formula, response=NULL,
     mainfit$sample <- NULL
   
   if(eval.loglik){
-    cat("Evaluating log-likelihood at the estimate. ")
+    message("Evaluating log-likelihood at the estimate. ", appendLF=FALSE)
     mainfit<-logLik.ergm(mainfit, add=TRUE, control=control$loglik.control, verbose=verbose)
   }
   
@@ -524,8 +526,8 @@ ergm <- function(formula, response=NULL,
   ergm.stopCluster(clus)
   
   if (MCMCflag) {
-    cat("\nThis model was fit using MCMC.  To examine model diagnostics", 
-        "and check for degeneracy, use the mcmc.diagnostics() function.\n")
+    message("This model was fit using MCMC.  To examine model diagnostics ", 
+        "and check for degeneracy, use the mcmc.diagnostics() function.")
   }
   
   mainfit
