@@ -49,7 +49,7 @@ ergm.coefficient.degeneracy <- function(object,
                           fast=TRUE,
                           test.only=FALSE,
                           verbose=FALSE) {
-  check.control.class(control, "ergm")
+  check.control.class("ergm", "ergm.coefficient.degeneracy")
   if(!is.ergm(object)){
     stop("A ergm object argument must be given.")
   }
