@@ -44,7 +44,7 @@ ergm.maple<-function(pl, m, init=NULL,
                     save.glm=TRUE,
                     theta1=NULL, verbose=FALSE, ...) {
   if(MPLEtype=="penalized"){
-   if(verbose) cat("Using penalized MPLE.\n")
+   if(verbose) message("Using penalized MPLE.")
    mplefit <- ergm.pen.glm(
                   pl$zy ~ pl$xmat -1 + offset(pl$foffset),
                   data=data.frame(pl$xmat), weights=pl$wend,
