@@ -98,7 +98,7 @@ gof.ergm <- function (object, ...,
                       constraints=NULL,
                       control=control.gof.ergm(),
                       verbose=FALSE) {
-  check.control.class(c("gof.ergm","gof.formula"))
+  check.control.class(c("gof.ergm","gof.formula"), "gof.ergm")
   control.toplevel(...)
   nw <- as.network(object$network)
 
@@ -157,14 +157,14 @@ gof.formula <- function(object, ...,
                         control=control.gof.formula(),
 			unconditional=TRUE,
                         verbose=FALSE) {
-  check.control.class(c("gof.formula","gof.ergm"))
+  check.control.class(c("gof.formula","gof.ergm"), "ERGM gof.formula")
   control.toplevel(...)
 
   if("response" %in% names(list(...))) stop("GoF for valued ERGMs is not implemented at this time.")
 
   if(!is.null(control$seed)) {set.seed(as.integer(control$seed))}
   if (verbose) 
-    cat("Starting GOF for the given ERGM formula.\n")
+    message("Starting GOF for the given ERGM formula.")
   # Unused code
   coefmissing <- NULL
   # get network
@@ -241,7 +241,7 @@ gof.formula <- function(object, ...,
 
   # If missing simulate from the conditional model
   if(network.naedgecount(nw) & unconditional){
-   if(verbose){cat("Conditional simulations for missing fit\n")}
+   if(verbose){message("Conditional simulations for missing fit")}
    if(is.null(coefmissing)){coefmissing <- coef}
    constraints.obs<-ergm.update.formula(constraints,~.+observed)
    SimCond <- gof(object=object, coef=coefmissing,
@@ -270,7 +270,7 @@ gof.formula <- function(object, ...,
   # Calculate network statistics for the observed graph
   # Set up the output arrays of sim variables
   if(verbose)
-    cat("Calculating observed network statistics.\n")
+    message("Calculating observed network statistics.")
   
   if ('model' %in% all.gof.vars) {
    if(!network.naedgecount(nw) | !unconditional){
@@ -398,12 +398,12 @@ gof.formula <- function(object, ...,
 # network.list object
 
   if(verbose)
-    cat("Starting simulations.\n")
+    message("Starting simulations.")
 
   tempnet <- nw
   for (i in 1:control$nsim) {
     if(verbose){
-      cat("Sim",i,"of",control$nsim,": ")
+      message("Sim ",i," of ",control$nsim,": ",appendLF=FALSE)
     }
     if(network.naedgecount(nw) & !unconditional){tempnet <- nw}
     tempnet <- simulate(object, nsim=1, coef=coef,
@@ -468,7 +468,7 @@ gof.formula <- function(object, ...,
     }
   }
   if(verbose){
-    cat("\n")
+    message("")
   }
 
   # calculate p-values
