@@ -76,7 +76,7 @@ simulate.ergm <- function(object, nsim=1, seed=NULL,
                           sequential=TRUE,
                           control=control.simulate.ergm(),
                           verbose=FALSE, ...) {
-  check.control.class(c("simulate.ergm","simulate.formula"))
+  check.control.class(c("simulate.ergm","simulate.formula"), "simulate.ergm")
   control.toplevel(...)
   control.transfer <- c("MCMC.burnin", "MCMC.interval", "MCMC.prop.weights", "MCMC.prop.args", "MCMC.packagenames", "MCMC.init.maxedges","parallel","parallel.type","parallel.version.check")
   for(arg in control.transfer)
@@ -104,7 +104,7 @@ simulate.formula <- function(object, nsim=1, seed=NULL,
                                sequential=TRUE,
                                control=control.simulate.formula(),
                                verbose=FALSE, ...) {
-  check.control.class(myname="ERGM simulate.formula")
+  check.control.class("simulate.formula", myname="ERGM simulate.formula")
   control.toplevel(...)
   
   if(!is.null(seed)) {set.seed(as.integer(seed))}
@@ -170,8 +170,8 @@ simulate.formula <- function(object, nsim=1, seed=NULL,
   
   # Explain how many iterations and steps will ensue if verbose==TRUE
   if (verbose) {
-    cat (paste ("Starting MCMC iterations to generate ", nsim,
-                " network", ifelse(nsim>1,"s\n","\n"), sep=""))
+    message(paste ("Starting MCMC iterations to generate ", nsim,
+                " network", ifelse(nsim>1,"s","")))
   }
 
   nthreads <- max(
@@ -243,7 +243,7 @@ simulate.formula <- function(object, nsim=1, seed=NULL,
         curstats <- curstats + z$statsmatrix
       }
 
-      if(verbose){cat(sprintf("Finished simulation %d of %d.\n",i, nsim))}
+      if(verbose){message(sprintf("Finished simulation %d of %d.",i, nsim))}
     }
     
     # done with parallel cluster
