@@ -7,8 +7,8 @@
  *
  *  Copyright 2003-2017 Statnet Commons
  */
-#include "changestats.dgw_sp.h"
 
+#include "changestats.dgw_sp.h"
 
 /**************************
  dsp Calculation functions
@@ -504,8 +504,8 @@ D_CHANGESTAT_FN(d_dgwdsp) {
   oneexpa = 1.0-exp(-alpha);    /*Precompute (1-exp(-alpha))*/
   type=(int)INPUT_PARAM[1];     /*Get the ESP type code to be used*/
   maxesp=(int)INPUT_PARAM[2];   /*Get the max ESP cutoff to use*/
-  cs=alloca(maxesp*sizeof(double));     /*Allocate memory for the ESP changescores*/
-  dvec=alloca(maxesp*sizeof(double));   /*Allocate memory for the ESP vals*/
+  cs=Calloc(maxesp,double);     /*Allocate memory for the ESP changescores*/
+  dvec=Calloc(maxesp,double);   /*Allocate memory for the ESP vals*/
   for(i=0;i<maxesp;i++)         /*Initialize the ESP vals*/
     dvec[i]=i+1.0;
 
@@ -527,6 +527,8 @@ D_CHANGESTAT_FN(d_dgwdsp) {
     }
   }
   CHANGE_STAT[0]*=exp(alpha);
+  Free(cs);
+  Free(dvec);
 }
 
 
@@ -1104,8 +1106,8 @@ D_CHANGESTAT_FN(d_dgwesp) {
   oneexpa = 1.0-exp(-alpha);    /*Precompute (1-exp(-alpha))*/
   type=(int)INPUT_PARAM[1];     /*Get the ESP type code to be used*/
   maxesp=(int)INPUT_PARAM[2];   /*Get the max ESP cutoff to use*/
-  cs=alloca(maxesp*sizeof(double));     /*Allocate memory for the ESP changescores*/
-  dvec=alloca(maxesp*sizeof(double));   /*Allocate memory for the ESP vals*/
+  cs=Calloc(maxesp,double);     /*Allocate memory for the ESP changescores*/
+  dvec=Calloc(maxesp,double);   /*Allocate memory for the ESP vals*/
   for(i=0;i<maxesp;i++)         /*Initialize the ESP vals*/
     dvec[i]=i+1.0;
 
@@ -1127,6 +1129,9 @@ D_CHANGESTAT_FN(d_dgwesp) {
     }
   }
   CHANGE_STAT[0]*=exp(alpha);
+
+  Free(cs);
+  Free(dvec);
 }
 
 
@@ -1158,8 +1163,8 @@ D_CHANGESTAT_FN(d_dnsp) {
   ZERO_ALL_CHANGESTATS(i);
   type=(int)INPUT_PARAM[0];     /*Get the ESP type code to be used*/
   dvec=INPUT_PARAM+1;           /*Get the pointer to the ESP stats list*/
-  cs_esp=alloca(N_CHANGE_STATS*sizeof(double));     /*Allocate memory for the DSP changescores*/
-  cs_dsp=alloca(N_CHANGE_STATS*sizeof(double));     /*Allocate memory for the DSP changescores*/
+  cs_esp=Calloc(N_CHANGE_STATS,double);     /*Allocate memory for the DSP changescores*/
+  cs_dsp=Calloc(N_CHANGE_STATS,double);     /*Allocate memory for the DSP changescores*/
 
   /*Obtain the ESP changescores (by type)*/
   switch(type){
@@ -1192,6 +1197,9 @@ D_CHANGESTAT_FN(d_dnsp) {
   
   for(i=0;i<N_CHANGE_STATS;i++)
     CHANGE_STAT[i]=(cs_dsp[i]-cs_esp[i]);
+
+  Free(cs_esp);
+  Free(cs_dsp);
 }
 
 
@@ -1221,12 +1229,12 @@ D_CHANGESTAT_FN(d_dgwnsp) {
   oneexpa = 1.0-exp(-alpha);    /*Precompute (1-exp(-alpha))*/
   type=(int)INPUT_PARAM[1];     /*Get the ESP type code to be used*/
   maxesp=(int)INPUT_PARAM[2];   /*Get the max ESP cutoff to use*/
-  cs_esp=alloca(maxesp*sizeof(double));     /*Allocate memory for the ESP changescores*/
-  dvec=alloca(maxesp*sizeof(double));   /*Allocate memory for the ESP vals*/
+  cs_esp=Calloc(maxesp,double);     /*Allocate memory for the ESP changescores*/
+  dvec=Calloc(maxesp,double);   /*Allocate memory for the ESP vals*/
   for(i=0;i<maxesp;i++)         /*Initialize the ESP vals*/
     dvec[i]=i+1.0;
   
-  cs_dsp=alloca(maxesp*sizeof(double));     /*Allocate memory for the ESP changescores*/
+  cs_dsp=Calloc(maxesp,double);     /*Allocate memory for the ESP changescores*/
 
   /*Obtain the changescores (by type)*/
   switch(type){
@@ -1262,6 +1270,9 @@ D_CHANGESTAT_FN(d_dgwnsp) {
       CHANGE_STAT[0]+=(1.0-pow(oneexpa,dvec[i]))*(cs_dsp[i]-cs_esp[i]);
   CHANGE_STAT[0]*=exp(alpha);
 
+  Free(cs_esp);
+  Free(cs_dsp);
+  Free(dvec);  
 }
 
 
